# -*- coding: utf-8 -*-
from plone.app.textfield import RichText
from plone.autoform import directives
from plone.supermodel import model
from redturtle.bandi import bandiMessageFactory as _
from z3c.form.browser.checkbox import CheckBoxFieldWidget
from plone.app.z3cform.widget import AjaxSelectFieldWidget
from z3c.form.browser.radio import RadioFieldWidget
from zope import schema
from redturtle.bandi import bandiMessageFactory as _rtbando
from redturtle.bandi.interfaces.bandoSchema import IBandoSchema, getDefaultEnte
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.autoform import directives as form


class IBandoAgidSchema(IBandoSchema):
    """ A Dexterity schema for Annoucements """

    form.order_after(riferimenti_bando="IRichTextBehavior.text")
    riferimenti_bando = RichText(
        title=_(
            "riferimenti_bando_agid_label", default=u"Ulteriori informazioni"
        ),
        description=_(
            "riferimenti_bando_agid_help",
            default=u"Ulteriori informazioni non previste negli altri campi;"
            " si può trattare di contatti o note informative la cui conoscenza"
            " è indispensabile per la partecipazione al bando",
        ),
        required=False,
    )

    form.order_after(chiusura_procedimento_bando="IRichTextBehavior.text")
    chiusura_procedimento_bando = schema.Date(
        title=_rtbando(
            "chiusura_procedimento_bando_label",
            default=u"Closing date procedure",
        ),
        description=_rtbando("chiusura_procedimento_bando_help", default=u""),
        required=False,
    )

    form.order_after(scadenza_bando="IRichTextBehavior.text")
    scadenza_bando = schema.Datetime(
        title=_rtbando(
            "scadenza_bando_label", default=u"Expiration date and time"
        ),
        description=_rtbando(
            "scadenza_bando_help",
            default=u"Deadline to participate in the announcement",
        ),
        required=False,
    )

    form.order_after(scadenza_domande_bando="IRichTextBehavior.text")
    scadenza_domande_bando = schema.Datetime(
        title=_(
            "scadenza_domande_bando_label",
            default=u"Termine per le richieste di chiarimenti",
        ),
        description=_(
            "scadenza_domande_bando_help",
            default=u"Data entro la quale sarà possibile far pervenire domande"
            " e richieste di chiarimento a chi eroga il bando",
        ),
        required=False,
    )

    form.order_after(ente_bando="IRichTextBehavior.text")
    directives.widget(
        "ente_bando",
        AjaxSelectFieldWidget,
        vocabulary="redturtle.bandi.enti.vocabulary",
    )
    ente_bando = schema.Tuple(
        title=_rtbando(u"ente_label", default=u"Authority"),
        description=_rtbando(
            u"ente_help", default=u"Select some authorities."
        ),
        required=False,
        defaultFactory=getDefaultEnte,
        value_type=schema.TextLine(),
        missing_value=None,
    )

    form.order_after(destinatari="IRichTextBehavior.text")
    directives.widget(destinatari=CheckBoxFieldWidget)
    destinatari = schema.List(
        title=_rtbando("destinatari_label", default=u"Recipients"),
        description=_rtbando("destinatari_help", default=""),
        required=True,
        value_type=schema.Choice(
            vocabulary="redturtle.bandi.destinatari.vocabulary"
        ),
    )

    form.order_after(tipologia_bando="IRichTextBehavior.text")
    directives.widget(tipologia_bando=RadioFieldWidget)
    tipologia_bando = schema.Choice(
        title=_rtbando("tipologia_bando_label", default=u"Announcement type"),
        description=_rtbando("tipologia_bando_help", default=""),
        vocabulary="redturtle.bandi.tipologia.vocabulary",
        required=True,
    )

    ufficio_responsabile = RelationList(
        title=_(
            "ufficio_responsabile_label",
            default="Ufficio responsabile del documento",
        ),
        description=_(
            "ufficio_responsabile_help",
            default="Seleziona l'ufficio responsabile di questo documento.",
        ),
        required=False,
        default=[],
        value_type=RelationChoice(
            title=_(u"Ufficio responsabile"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
    )

    area_responsabile = RelationList(
        title=_(
            "area_responsabile_label",
            default="Area responsabile del documento",
        ),
        description=_(
            "area_responsabile_help",
            default="Seleziona l'area amministrativa responsabile del "
            "documento.",
        ),
        required=False,
        default=[],
        value_type=RelationChoice(
            title=_(u"Area"), vocabulary="plone.app.vocabularies.Catalog"
        ),
    )

    form.widget(
        "ufficio_responsabile",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 1,
            "selectableTypes": ["UnitaOrganizzativa"],
        },
    )
    form.widget(
        "area_responsabile",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 1,
            "selectableTypes": ["UnitaOrganizzativa"],
        },
    )

    model.fieldset(
        "correlati",
        label=_("correlati_label", default="Contenuti collegati"),
        fields=["area_responsabile", "ufficio_responsabile"],
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.interfaces.unita_organizzativa import (
    IUnitaOrganizzativa,
)
from plone.dexterity.content import Container
from zope.interface import implementer


@implementer(IUnitaOrganizzativa)
class UnitaOrganizzativa(Container):
    '''
    '''



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.dexterity.interfaces import IDexterityContent
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice, RelationList
from zope.component import adapter
from zope.interface import provider, implementer


@provider(IFormFieldProvider)
class IStruttureCorrelate(model.Schema):

    strutture_politiche = RelationList(
        title=u"Strutture politiche coinvolte",
        default=[],
        value_type=RelationChoice(
            title=_(u"Struttura politica coinvolta"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
        required=False,
        missing_value=(),
        description=_(
            "strutture_politiche_help",
            default="Seleziona la lista delle strutture politiche coinvolte.",
        ),
    )
    form.widget(
        "strutture_politiche",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 10,
            "selectableTypes": ["UnitaOrganizzativa"],
        },
    )

    model.fieldset(
        "informazioni",
        label=_("informazioni_label", default=u"Ulteriori informazioni"),
        fields=["strutture_politiche"],
    )


@implementer(IStruttureCorrelate)
@adapter(IDexterityContent)
class StruttureCorrelate(object):
    """
    """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from collective import dexteritytextindexer
from design.plone.contenttypes import _
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.autoform import directives as form
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from zope.schema import TextLine


class IPaginaArgomento(model.Schema):
    """ Marker interface for PaginaArgomento
    """

    icona = TextLine(
        title=_(u"icona", default=u"Icona"),
        description=_(
            "icona_help",
            default="Puoi selezionare un’icona fra quelle proposte nel menu a"
            " tendina oppure puoi scrivere/incollare nel campo di testo il"
            " nome di un’icona di fontawsome 5",
        ),
        required=False,
    )

    unita_amministrative_responsabili = RelationList(
        title=_(
            u"unita_amministrative_responsabili",
            default=u"Unità amministrative responsabili",
        ),
        required=False,
        default=[],
        value_type=RelationChoice(
            title=_(u"Unità amministrative responsabili"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
        description=_(
            "unita_amministrative_responsabili_help",
            default="Seleziona la lista delle unità amministrative"
            " responsabili di questo argomento.",
        ),
    )
    form.widget(
        "unita_amministrative_responsabili",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 10,
            "selectableTypes": ["UnitaOrganizzativa"],
        },
    )

    form.order_after(
        unita_amministrative_responsabili="ILeadImageBehavior.image_caption"
    )

    # SearchableText fields
    dexteritytextindexer.searchable("unita_amministrative_responsabili")



# -*- coding: utf-8 -*-
from plone.supermodel import model
from plone.app.textfield import RichText
from zope import schema
from design.plone.contenttypes import _


class IPratica(model.Schema):
    """ Marker interface for Pratica
    """

    numero_protocollo = schema.TextLine(
        title=_(u'numero_protocollo', default=u'Numero protocollo'),
        required=True,
    )

    ufficio_riferimento = schema.Choice(
        title=_(u'ufficio_riferimento', default=u'Ufficio di riferimento'),
        # vocabolario di riferimento sara' la lista degli uffici di riferimento
        vocabulary='design.plone.contenttypes.Mockup',
        required=False,
    )

    # questo viene gestito dal workflow di Plone ma fa riferimento ad una
    # tassonomia "Lista stati di una pratica"
    stato_pratica = schema.TextLine(
        title=_(u'stato_pratica', default=u'Stato della pratica'),
        required=True,
    )

    # TODO: aggiungere tassonomia e vocabolario rilevante
    servizio_origine = schema.Choice(
        title=_(
            u'servizio_origine_pratica', default=u'Servizio che origina la pratica'
        ),
        # vocabolario di riferimento sara' il servizio che genera il task e
        # permette di soddisfarlo
        vocabulary='design.plone.contenttypes.Mockup',
        required=False,
    )

    contenuto = RichText(
        title=_(u'contenuto', default=u'Contenuto'), required=True
    )

    contatti = RichText(
        title=_(u'contatti', default=u'Contatti'), required=True
    )

    azioni_utente = schema.Choice(
        title=_(u'azioni_utente', default=u'Azioni utente'),
        # vocabolario di riferimento sara' la tassonomia "Lista azioni pratica"
        vocabulary='design.plone.contenttypes.ListaAzioniPratica',
        required=True,
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.dexterity.interfaces import IDexterityContent
from zope.globalrequest import getRequest
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


class VocabItem(object):
    def __init__(self, token, value):
        self.token = token
        self.value = value


@implementer(IVocabularyFactory)
class Mockup(object):
    """
    """

    def __call__(self, context):
        # Just an example list of content for our vocabulary,
        # this can be any static or dynamic data, a catalog result for example.
        items = [
            VocabItem(u'sony-a7r-iii', _(u'Sony Aplha 7R III')),
            VocabItem(u'canon-5d-iv', _(u'Canon 5D IV')),
            VocabItem(u'pippo', _(u'Pippo')),
            VocabItem(u'pluto', _(u'Pluto')),
            VocabItem(u'paperino', _(u'Paperino')),
            VocabItem(u'giovanni', _(u'Giovanni')),
        ]

        # Fix context if you are using the vocabulary in DataGridField.
        # See https://github.com/collective/collective.z3cform.datagridfield/issues/31:  # NOQA: 501
        if not IDexterityContent.providedBy(context):
            req = getRequest()
            context = req.PARENTS[0]

        # create a list of SimpleTerm items:
        terms = []
        for item in items:
            terms.append(
                SimpleTerm(
                    value=item.token, token=str(item.token), title=item.value
                )
            )
        # Create a SimpleVocabulary from the terms list and return it:
        return SimpleVocabulary(terms)


MockupFactory = Mockup()



# -*- coding: utf-8 -*-
from collective import dexteritytextindexer
from collective.venue.interfaces import IVenue
from design.plone.contenttypes import _
from plone.app.textfield import RichText
from plone.autoform.interfaces import IFormFieldProvider
from plone.supermodel import model
from zope import schema
from zope.component import adapter
from zope.interface import provider, implementer
from design.plone.contenttypes.interfaces.unita_organizzativa import (
    IUnitaOrganizzativa,
)


class IContatti(model.Schema):
    """
    """

    telefono = schema.TextLine(
        title=_(u"telefono_label", default=u"Telefono"),
        description=_(
            u"telefono_help",
            default=u"Indicare un riferimento telefonico per poter contattare"
            " i referenti.",
        ),
        required=False,
    )

    fax = schema.TextLine(
        title=_(u"fax_label", default=u"Fax"),
        description=_(u"fax_help", default=u"Indicare un numero di fax."),
        required=False,
    )

    email = schema.TextLine(
        title=_(u"email_label", default=u"E-mail"),
        description=_(
            u"email_help",
            default=u"Indicare un indirizzo mail per poter contattare"
            " i referenti.",
        ),
        required=False,
    )

    pec = schema.TextLine(
        title=_(u"pec_label", default=u"Pec"),
        description=_(
            u"pec_help",
            default=u"Indicare un indirizzo pec per poter contattare"
            " i referenti.",
        ),
        required=False,
    )

    web = schema.TextLine(
        title=_(u"web_label", default=u"Sito web"),
        description=_(
            "web_help", default="Indicare un indirizzo web di riferimento."
        ),
        required=False,
    )

    orario_pubblico = RichText(
        title=_(u"orario_pubblico_label", default=u"Orario per il pubblico"),
        description=_(
            u"orario_pubblico_help",
            default=u"Indicare eventuali orari di accesso al pubblico",
        ),
        required=False,
    )

    dexteritytextindexer.searchable("orario_pubblico")


@provider(IFormFieldProvider)
class IContattiUnitaOrganizzativa(IContatti):
    model.fieldset(
        "contatti",
        label=_("contatti_label", default=u"Contatti"),
        fields=["telefono", "fax", "email", "pec", "web", "orario_pubblico"],
    )


@provider(IFormFieldProvider)
class IContattiVenue(IContatti):

    model.fieldset(
        "orari",
        label=_("orari_label", default=u"Orari di apertura"),
        fields=["orario_pubblico"],
    )

    model.fieldset(
        "contatti",
        label=_("contatti_label", default=u"Contatti"),
        fields=["telefono", "fax", "email", "pec", "web"],
    )


@implementer(IContattiUnitaOrganizzativa)
@adapter(IUnitaOrganizzativa)
class ContattiUnitaOrganizzativa(object):
    """
    """

    def __init__(self, context):
        self.context = context


@implementer(IContattiVenue)
@adapter(IVenue)
class ContattiVenue(object):
    """
    """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.namedfile import field
from plone.supermodel import model
from zope import schema


class IMessaggio(model.Schema):
    """ Marker interface for Messaggio
    """

    data_messaggio = schema.Date(
        title=_(u"data_messaggio", default=u"Data del messaggio"), required=True
    )

    # "Titolo del messaggio" e "Descrizione" vengono lasciati in titolo e
    # descrizione di Plone

    # TODO: aggiungere tassonomia delle tipologie di azioni richieste al
    # cittadino
    azioni_richieste = schema.Choice(
        title=_(u"azioni_richieste", default=u"Azioni richieste"),
        required=True,
        vocabulary="design.plone.contenttypes.Mockup",
    )

    azioni_pratica = schema.Choice(
        title=_(u"azioni_pratica", default=u"Azioni"),
        # vocabolario di riferimento sara' la tassonomia "Lista azioni pratica"
        vocabulary="design.plone.contenttypes.ListaAzioniPratica",
        required=True,
    )

    pratica_associata = schema.TextLine(
        title=_(u"pratica_associata", default=u"Pratica associata"), required=True
    )

    # come gestiamo "Servizio che genera il messaggio"? Link, ref, RichText
    # con solo il link alla pagina?

    data_scadenza_procedura = schema.Date(
        title=_(
            u"data_scadenza_procedura", default=u"Data di scadenza della procedura"
        ),
        required=False,
    )

    # TODO: inserire tassonomia contenente le tipologie di documenti
    tipologia_documento = schema.Choice(
        title=_(u"tipologia_documento", default=u"Tipologia documento"),
        required=False,
        vocabulary="design.plone.contenttypes.Mockup",
        missing_value=(),
    )

    documenti_allegati = field.NamedFile(
        title=_(u"documenti_allegati", default=u"Documenti allegati"), required=False
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.namedfile import field
from plone.supermodel import model
from zope import schema


class IRicevutaPagamento(model.Schema):
    """ Marker interface for RicevutaPagamento
    """

    numero_protocollo = schema.Id(
        title=_(u'numero_protocollo', default=u'Numero protocollo'),
        required=True,
    )

    stampa_ricevuta = field.NamedFile(
        title=_(u'stampa_ricevuta', default=u'Stampa ricevuta'), required=True
    )

    data_pagamento = schema.Date(
        title=_(u'data_pagamento', default=u'Data pagamento'), required=True
    )

    importo_pagato = schema.TextLine(
        title=_(u'importo_pagato', default=u'Importo pagato'), required=True
    )

    modalita_pagamento = schema.TextLine(
        title=_(u'modalita_pagamento', default=u'Modalità pagamento'),
        required=True,
    )

    # TODO: aggiungere tassonomia e vocabolario rilevante
    servizio_origine = schema.Choice(
        title=_(
            u'servizio_origine_ricevuta', default=u'Servizio che origina la pratica'
        ),
        # vocabolario di riferimento sara' il servizio che genera il task e
        # permette di soddisfarlo
        vocabulary='design.plone.contenttypes.Mockup',
        required=False,
    )

    pratica_associata = field.NamedFile(
        title=_(
            u'pratica_associata_ricevuta', default=u'Pratica associata al pagamento'
        ),
        required=True,
    )

    # TODO: capire se ci sono altri esiti oltre ai banali "accettato",
    # "rifiutato", "in attesa di conferma",
    # e costruire di conseguenza un vocabolario adeguato
    esito = schema.Choice(
        title=_(u'esito', default=u'Esito'),
        vocabulary='design.plone.contenttypes.Mockup',
        required=True,
    )

    allegato = field.NamedFile(
        title=_(u'allegato', default=u'Allegato'), required=False
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.controlpanels.vocabularies import (
    IVocabulariesControlPanel,
)
from plone.restapi.controlpanels import RegistryConfigletPanel
from zope.component import adapter
from zope.interface import Interface


@adapter(Interface, Interface)
class VocabulariesControlpanel(RegistryConfigletPanel):
    schema = IVocabulariesControlPanel
    configlet_id = "DesignPloneVocabularies"
    configlet_category_id = "Products"
    schema_prefix = None



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
from plone.app.registry.browser.controlpanel import RegistryEditForm
from plone.z3cform import layout
from z3c.form import form
from zope.schema import List, TextLine
from zope.interface import Interface


class IVocabulariesControlPanel(Interface):
    tipologie_notizia = List(
        title=_(u"Tipologie notizia"),
        description=_(
            u"Inserisci i valori utilizzabili per le tipologie di"
            " notizia; inserisci i valori uno per riga"
        ),
        required=True,
        default=[],
        value_type=TextLine(),
    )

    tipologie_unita_organizzativa = List(
        title=_(u"Tipologie unita organizzativa"),
        description=_(
            u"Inserisci i valori utilizzabili per le tipologie di"
            " unita organizzativa; inserisci i valori uno per riga"
        ),
        required=True,
        default=[],
        value_type=TextLine(),
    )

    lead_image_dimension = List(
        title=_(u"Indicare le dimensioni delle lead image dei contenuti"),
        description=_(
            u"Inserire le dimensioni nella forma di esempio PortalType|900x900"
        ),
        required=True,
        default=[],
        value_type=TextLine(),
    )


class VocabulariesControlPanelForm(RegistryEditForm):
    form.extends(RegistryEditForm)
    schema = IVocabulariesControlPanel
    id = "design-plone-vocabularies-control-panel"
    label = _(u"Vocabolari")


VocabulariesControlPanelView = layout.wrap_form(
    VocabulariesControlPanelForm, ControlPanelFormWrapper
)
VocabulariesControlPanelView.label = _(u"Vocabolari")



# -*- coding: utf-8 -*-

"""Setup tests for this package."""
from design.plone.contenttypes.testing import (
    DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
    DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
    # DESIGN_PLONE_CONTENTTYPES_FUNCTIONAL_TESTING,
)
from plone import api
from plone.app.testing import (
    SITE_OWNER_NAME,
    SITE_OWNER_PASSWORD,
    TEST_USER_ID,
    setRoles,
)
# from plone.app.textfield.value import RichTextValue
from plone.restapi.testing import RelativeSession
from Products.CMFPlone.utils import getToolByName
from transaction import commit
from z3c.relationfield import RelationValue
from zope.component import getUtility
from zope.intid.interfaces import IIntIds

import unittest


class TestServizio(unittest.TestCase):
    """Test that design.plone.contenttypes is properly installed."""

    layer = DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING

    def setUp(self):
        self.app = self.layer["app"]
        self.portal = self.layer["portal"]
        self.portal_url = self.portal.absolute_url()
        setRoles(self.portal, TEST_USER_ID, ["Manager"])

        self.api_session = RelativeSession(self.portal_url)
        self.api_session.headers.update({"Accept": "application/json"})
        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)

        intids = getUtility(IIntIds)
        self.news = api.content.create(
            container=self.portal, type="News Item", title="TestNews"
        )
        self.luogo = api.content.create(
            container=self.portal, type="Venue", title="Luogo",
            street="Street Foo",
            zip_code="1234",
            city="Rome",
            country="Italy",
            orario_pubblico="",
            telefono="123456",
            email="foo@foo.com",
            pec="foo@pec.com",
            riferimento_telefonico_struttura="9876",
            riferimento_mail_struttura="bar@bar.com",
            riferimento_pec_struttura="bar@pec.com",
            web="http://www.plone.org",
        )
        luogo = RelationValue(intids.getId(self.luogo))

        self.uo = api.content.create(
            container=self.portal, type="UnitaOrganizzativa", title="TestUO",
            sede=[luogo]
        )
        uo = RelationValue(intids.getId(self.uo))

        self.service = api.content.create(
            container=self.portal,
            type="Servizio",
            title="TestService",
            ufficio_responsabile=[uo]
        )

        self.news.a_cura_di = [uo]
        pcatalog = getToolByName(self.portal, "portal_catalog")
        pcatalog.manage_reindexIndex(ids=["ufficio_responsabile", "news_uo"])
        commit()

    def tearDown(self):
        self.api_session.close()

    def test_uo_service_related_news(self):
        response = self.api_session.get(self.uo.absolute_url() + "?fullobjects")
        self.assertTrue(
            response.json()["related_news"][0]["@id"], self.news.absolute_url()
        )

    def test_uo_service_related_service(self):
        response = self.api_session.get(self.uo.absolute_url() + "?fullobjects")
        self.assertTrue(
            response.json()["servizi_offerti"][0]["@id"],
            self.service.absolute_url()
        )

    def test_uo_sede_data(self):
        response = self.api_session.get(self.uo.absolute_url() + "?fullobjects")
        sede = response.json()["sede"][0]
        fields = [
            "street",
            "zip_code",
            "city",
            "country",
            "orario_pubblico",
            "telefono",
            "email",
            "pec",
            "web",
            "riferimento_telefonico_struttura",
            "riferimento_mail_struttura",
            "riferimento_pec_struttura",
        ]
        for field in fields:
            self.assertEqual(
                sede[field],
                getattr(self.luogo, field, '')
            )


class TestUO(unittest.TestCase):
    layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]

    def test_behaviors_enabled_for_uo(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["UnitaOrganizzativa"].behaviors,
            (
                "plone.namefromtitle",
                "plone.allowdiscussion",
                "plone.excludefromnavigation",
                "plone.shortname",
                "plone.ownership",
                "plone.publication",
                "plone.categorization",
                "plone.basic",
                "plone.locking",
                "plone.leadimage",
                "plone.relateditems",
                "design.plone.contenttypes.behavior.address_uo",
                "design.plone.contenttypes.behavior.geolocation_uo",
                "design.plone.contenttypes.behavior.contatti_uo",
                "design.plone.contenttypes.behavior.argomenti",
                "collective.dexteritytextindexer",
                "design.plone.contenttypes.behavior.additional_help_infos",
            ),
        )

    def test_uo_ct_title(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            "Unita Organizzativa", portal_types["UnitaOrganizzativa"].title
        )


#  DISABILITATO perchè nei test non indicizza niente nel searchabletext, non so perché
# class TestUOSearchableText(unittest.TestCase):
#     layer = DESIGN_PLONE_CONTENTTYPES_FUNCTIONAL_TESTING

#     def setUp(self):
#         """Custom shared utility setup for tests."""
#         self.portal = self.layer["portal"]
#         self.catalog = api.portal.get_tool(name="portal_catalog")
#         setRoles(self.portal, TEST_USER_ID, ["Manager"])

#         self.person = api.content.create(
#             container=self.portal, type="Persona", title="John Doe"
#         )

# def test_competenze_indexed(self):
#     uo = api.content.create(
#         container=self.portal,
#         type="UnitaOrganizzativa",
#         title="UO",
#         # competenze=RichTextValue(
#         #     raw="destinatari",
#         #     mimeType="text/html",
#         #     outputMimeType="text/html",
#         #     encoding="utf-8",
#         # ),
#     )
#     res = api.content.find(UID=uo.UID())
#     rid = res[0].getRID()
#     index_data = self.catalog.getIndexDataForRID(rid)

#     import pdb

#     pdb.set_trace()
#     res = api.content.find(SearchableText="destinatari")

#     self.assertEqual(len(res), 1)
#     self.assertEqual(res[0].UID, servizio.UID())



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


@implementer(IVocabularyFactory)
class TipologieDocumento(object):
    """"""

    def __call__(self, context):
        values = [
            _("Documenti albo pretorio"),
            _("Modulistica"),
            _("Documenti funzionamento interno"),
            _("Atti normativi"),
            _("Accordi tra enti"),
            _("Documenti attività politica"),
            _("Documenti (tecnici) di supporto"),
            _("Istanze"),
            _("Dataset"),
        ]
        terms = [
            SimpleTerm(
                value="", token="", title=_("-- seleziona un valore --")
            )
        ]
        terms.extend([SimpleTerm(value=x, token=x, title=x) for x in values])

        return SimpleVocabulary(terms)


TipologieDocumentoFactory = TipologieDocumento()



# -*- coding: utf-8 -*-
from collective import dexteritytextindexer
from design.plone.contenttypes import _
from plone.app.textfield import RichText
from plone.autoform.interfaces import IFormFieldProvider
from plone.dexterity.interfaces import IDexterityContent
from plone.supermodel import model
from zope.component import adapter
from zope.interface import provider, implementer


# TODO: valutare se aggiungere 'box_aiuto', in alcuni CT e' obbligatorio
# e bisognerebbe metterlo unifrme per tutti in barba alle linee guida
@provider(IFormFieldProvider)
class IAdditionalHelpInfos(model.Schema):

    ulteriori_informazioni = RichText(
        title=_(u"ulteriori_informazioni", default=u"Ulteriori informazioni"),
        description=_(
            "ulteriori_informazioni_help",
            default="Ulteriori informazioni non contemplate" " dai campi precedenti.",
        ),
        required=False,
    )

    model.fieldset(
        "informazioni",
        label=_("informazioni_label", default=u"Ulteriori informazioni"),
        fields=["ulteriori_informazioni"],
    )

    dexteritytextindexer.searchable("ulteriori_informazioni")


@implementer(IAdditionalHelpInfos)
@adapter(IDexterityContent)
class AdditionalHelpInfos(object):
    """
    """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.contenttypes.interfaces import IDesignPloneContenttypesLayer
from plone.restapi.interfaces import ISerializeToJsonSummary
from plone.restapi.serializer.summary import (
    DefaultJSONSummarySerializer as BaseSerializer,
)
from zope.component import adapter
from zope.interface import implementer
from zope.interface import Interface


@implementer(ISerializeToJsonSummary)
@adapter(Interface, IDesignPloneContenttypesLayer)
class DefaultJSONSummarySerializer(BaseSerializer):
    def __call__(self):
        res = super(DefaultJSONSummarySerializer, self).__call__()
        res["id"] = self.context.id
        try:
            obj = self.context.getObject()
        except AttributeError:
            obj = self.context
        res["has_children"] = False
        try:
            if obj.aq_base.keys():
                res["has_children"] = True
        except AttributeError:
            return res
        return res



# -*- coding: utf-8 -*-
from plone import api
from copy import deepcopy
from plone.app.upgrade.utils import installOrReinstallProduct

import logging
import json

logger = logging.getLogger(__name__)

DEFAULT_PROFILE = "profile-design.plone.contenttypes:default"


def update_profile(context, profile):
    context.runImportStepFromProfile(DEFAULT_PROFILE, profile)


def update_types(context):
    update_profile(context, "typeinfo")


def update_rolemap(context):
    update_profile(context, "rolemap")


def update_registry(context):
    update_profile(context, "plone.app.registry", run_dependencies=False)


def update_catalog(context):
    update_profile(context, "catalog")


def update_controlpanel(context):
    update_profile(context, "controlpanel")


def remap_fields(mapping):
    pc = api.portal.get_tool(name="portal_catalog")
    brains = pc()
    tot = len(brains)
    logger.info("Trovati {} elementi da sistemare.".format(tot))
    # remap fields
    for brain in brains:
        item = brain.getObject()
        for old, new in mapping.items():
            value = getattr(item, old, None)
            if value:
                setattr(item, new, value)
                setattr(item, old, None)
                logger.info(
                    "- {url}: {old} -> {new}".format(
                        url=brain.getURL(), old=old, new=new
                    )
                )
                delattr(item, old)


def to_1001(context):

    update_types(context)

    # cleanup event behaviors
    portal_types = api.portal.get_tool(name="portal_types")
    behaviors = portal_types["Event"].behaviors
    to_remove = [
        "design.plone.contenttypes.behavior.luoghi_correlati",
        "design.plone.contenttypes.behavior.argomenti_evento",
        "design.plone.contenttypes.behavior.additional_help_infos_evento",
    ]
    portal_types["Event"].behaviors = tuple(
        [x for x in behaviors if x not in to_remove]
    )

    mapping = {
        # "descrizione_destinatari": "a_chi_si_rivolge",
        "canale_fisico": "dove_rivolgersi_extra",
        "canale_fisico_prenotazione": "prenota_appuntamento",
        "fasi_scadenze": "tempi_e_scadenze",
        "sedi_e_luoghi": "dove_rivolgersi",
        "box_aiuto": "ulteriori_informazioni",
        "riferimento_telefonico_luogo": "telefono",
        "riferimento_mail_luogo": "email",
    }
    remap_fields(mapping=mapping)


def to_1003(context):

    update_types(context)

    mapping = {
        "unita_amministrativa_responsabile": "unita_amministrative_responsabili",  # noqa
        "sedi": "sede",
        "contatto_reperibilita": "reperibilita",
        "evento_supportato_da": "supportato_da",
    }
    remap_fields(mapping=mapping)


def to_1005(context):
    def fix_index(blocks):
        for block in blocks.values():
            if block.get("@type", "") == "listing":
                for query in block.get("query", []):
                    if (
                        query["i"] == "argomenti_correlati"
                        or query["i"] == "tassonomia_argomenti"
                    ):  # noqa
                        query["i"] = "argomenti"
                        logger.info(" - {}".format(brain.getURL()))

    # fix root
    portal = api.portal.get()
    portal_blocks = json.loads(portal.blocks)
    fix_index(portal_blocks)
    portal.blocks = json.dumps(portal_blocks)

    logger.info("Fixing listing blocks.")
    for brain in api.content.find(
        object_provides="plone.restapi.behaviors.IBlocks"
    ):
        item = brain.getObject()
        blocks = deepcopy(getattr(item, "blocks", {}))
        if blocks:
            fix_index(blocks)
            item.blocks = blocks
    logger.info("** Reindexing items that refers to an argument **")
    for brain in api.portal.get_tool("portal_catalog")():
        item = brain.getObject()
        if getattr(item.aq_base, "tassonomia_argomenti", []):
            logger.info(" - {}".format(brain.getURL()))
            item.reindexObject(idxs=["argomenti"])


def to_1006(context):
    def fix_index(blocks):
        for block in blocks.values():
            if block.get("@type", "") == "listing":
                for query in block.get("query", []):
                    if (
                        query["i"] == "argomenti_correlati"
                        or query["i"] == "tassonomia_argomenti"
                        or query["i"] == "argomenti"
                    ):  # noqa
                        query["i"] = "argomenti"
                        query["v"] = [
                            x.Title for x in api.content.find(UID=query["v"])
                        ]
                        logger.info(" - {}".format(brain.getURL()))

    # fix root
    portal = api.portal.get()
    portal_blocks = json.loads(portal.blocks)
    fix_index(portal_blocks)
    portal.blocks = json.dumps(portal_blocks)

    logger.info("Fixing listing blocks.")
    for brain in api.content.find(
        object_provides="plone.restapi.behaviors.IBlocks"
    ):
        item = brain.getObject()
        blocks = deepcopy(getattr(item, "blocks", {}))
        if blocks:
            fix_index(blocks)
            item.blocks = blocks


def to_1007(context):
    for brain in api.content.find(portal_type="Persona"):
        item = brain.getObject()
        if item.email:
            item.email = [item.email]
        if item.telefono:
            item.telefono = [item.telefono]


def to_1008(context):
    installOrReinstallProduct(api.portal.get(), "redturtle.bandi")


def to_1009(context):
    def fix_index(blocks):
        """
        revert to tassonomia_argomenti
        """
        for block in blocks.values():
            if block.get("@type", "") == "listing":
                for query in block.get("query", []):
                    if query["i"] == "argomenti":
                        query["i"] = "tassonomia_argomenti"
                        logger.info(" - {}".format(brain.getURL()))

    # fix root
    portal = api.portal.get()
    portal_blocks = json.loads(portal.blocks)
    fix_index(portal_blocks)
    portal.blocks = json.dumps(portal_blocks)

    logger.info("Fixing listing blocks.")
    for brain in api.content.find(
        object_provides="plone.restapi.behaviors.IBlocks"
    ):
        item = brain.getObject()
        blocks = deepcopy(getattr(item, "blocks", {}))
        if blocks:
            fix_index(blocks)
            item.blocks = blocks
    logger.info("** Reindexing items that refers to an argument **")
    for brain in api.portal.get_tool("portal_catalog")():
        item = brain.getObject()
        if getattr(item.aq_base, "tassonomia_argomenti", []):
            logger.info(" - {}".format(brain.getURL()))
            item.reindexObject(idxs=["tassonomia_argomenti"])


def to_1010(context):
    pc = api.portal.get_tool(name="portal_catalog")
    pc.manage_reindexIndex(ids=["event_location"])


def to_1013(context):
    def fix_template_name(blocks):
        """
        revert to tassonomia_argomenti
        """
        found = False
        for block in blocks.values():
            if (
                block.get("@type", "") == "listing"
                and block.get("template", "") == "imageGallery"
            ):
                block["template"] = "photogallery"
                found = True
        return found

    # fix root
    logger.info(
        'Changing listing block template from "imageGallery" to "photogallery'
    )
    portal = api.portal.get()
    portal_blocks = json.loads(portal.blocks)
    to_update = fix_template_name(portal_blocks)
    fixed_items = []
    if to_update:
        portal.blocks = json.dumps(portal_blocks)
        fixed_items.append("Root")
    i = 0
    brains = api.content.find(
        object_provides="plone.restapi.behaviors.IBlocks"
    )
    tot = len(brains)
    for brain in brains:
        i += 1
        if i % 1000 == 0:
            logger.info("Progress: {}/{}".format(i, tot))
        item = brain.getObject()
        blocks = deepcopy(getattr(item, "blocks", {}))
        if blocks:
            to_update = fix_template_name(blocks)
            if to_update:
                item.blocks = blocks
                fixed_items.append(brain.getPath())

    logger.info("Finish")
    if fixed_items:
        logger.info("Updated items:")
        for fixed in fixed_items:
            logger.info("- {}".format(fixed))
    else:
        logger.info("No items affected.")


def to_1014(context):
    update_types(context)
    portal_types = api.portal.get_tool(name="portal_types")
    portal_types["Bando"].behaviors = tuple(
        [
            x
            for x in portal_types["Bando"].behaviors
            if x != "design.plone.contenttypes.behavior.argomenti"
        ]
    )


def to_1015(context):
    update_types(context)

    # cleanup trasparenza behavior from CTs
    portal_types = api.portal.get_tool(name="portal_types")
    service_behaviors = portal_types["Servizio"].behaviors
    to_remove = [
        "design.plone.contenttypes.behavior.trasparenza",
    ]
    portal_types["Servizio"].behaviors = tuple(
        [x for x in service_behaviors if x not in to_remove]
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.controlpanels.vocabularies import (
    IVocabulariesControlPanel,
)
from plone import api
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


class BaseVocabulary(object):
    def __call__(self, context):

        values = api.portal.get_registry_record(
            self.field, interface=IVocabulariesControlPanel, default=[]
        )
        if not values:
            return SimpleVocabulary([])

        terms = [SimpleTerm(value=x, token=x, title=x) for x in values]
        terms.insert(
            0,
            SimpleTerm(value="", token="", title="-- seleziona un valore --"),
        )

        return SimpleVocabulary(terms)


@implementer(IVocabularyFactory)
class TipologieNotizia(BaseVocabulary):
    field = "tipologie_notizia"


@implementer(IVocabularyFactory)
class TipologieUnitaOrganizzativaVocabulary(BaseVocabulary):
    field = "tipologie_unita_organizzativa"


@implementer(IVocabularyFactory)
class LeadImageDimension(BaseVocabulary):
    field = "lead_image_dimension"

    def __call__(self, context):

        values = api.portal.get_registry_record(
            self.field, interface=IVocabulariesControlPanel, default=[]
        )
        if not values:
            return SimpleVocabulary([])

        terms = []
        for value in values:
            token, title = value.split("|")
            terms.append(SimpleTerm(value=token, token=token, title=title))
        return SimpleVocabulary(terms)


LeadImageDimensionFactory = LeadImageDimension()
TipologieNotiziaFactory = TipologieNotizia()
TipologieUnitaOrganizzativaVocabularyFactory = (
    TipologieUnitaOrganizzativaVocabulary()
)



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.app.textfield import RichText
from plone.namedfile import field
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from zope import schema


class IDocumentoPersonale(model.Schema):
    """ Marker interface for DocumentoPersonale
    """

    protocollo = schema.TextLine(
        title=_(u"protocollo", default=u"Protocollo"), required=True
    )

    data_protocollo = schema.Date(
        title=_(u"data_protocollo", default=u"Data del protocollo"), required=True
    )

    immagine = field.NamedImage(
        title=_(u"immagine", default=u"Immagine"), required=False
    )

    pratica_associata = field.NamedFile(
        title=_(u"pratica_associata", default=u"Pratica associata"), required=True
    )

    servizio_origine = schema.Choice(
        title=_(u"servizio_origine", default=u"Servizio che genera il documento"),
        vocabulary="design.plone.contenttypes.Mockup",
        required=True,
    )

    # TODO: come gestiamo i campi "Tipologia del documento", "sottotipologia
    # del documento" e "lingua del documento"?

    # TODO: il vocabolario controllato da usare sara' "Argomenti di interesse
    #  pere gli utenti di un comune"
    argomenti_utenti = schema.Choice(
        title=_(u"argomenti_utenti", default=u"Argomenti utenti"),
        vocabulary="design.plone.contenttypes.Mockup",
        required=True,
    )

    oggetto = RichText(
        title=_(u"oggetto", default=u"Oggetto"),
        # non viene specificato se il campo e' obbligatorio o meno
        required=False,
    )

    # TODO: decidere se "link al documento" sara' un folder o un file. Se e'
    # un folder "formati disponibili" diventa un campo
    # generato facendo una query dei file presenti all'interno di "link al
    #  documento"?
    # Inserito come folder "Allegati" per il momento, magari si chiede

    # TODO: usare vocabolario dinamico per le tipologie di uffici (dovrebbe
    # rientrare nel content type "Unita' organizzativa")
    ufficio_responsabile = schema.Choice(
        title=_(
            u"ufficio_responsabile_documento_personale", default=u"Ufficio responsabile"
        ),
        required=True,
        vocabulary="design.plone.contenttypes.Mockup",
    )

    # TODO: usare vocabolario dinamico per le tipologie di aree amministrative
    # (dovrebbe rientrare nel content type "Unita' organizzativa")
    area_responsabile = schema.Choice(
        title=_(u"area_responsabile_documento_personale", default=u"Area responsabile"),
        required=True,
        vocabulary="design.plone.contenttypes.Mockup",
    )

    # TODO: usare vocabolario dinamico per le gli autori?
    autori = RelationList(
        title=u"Autore/i",
        default=[],
        value_type=RelationChoice(
            title=_(u"Autore"), vocabulary="plone.app.vocabularies.Catalog"
        ),
        required=False,
    )

    licenza_distribuzione = schema.TextLine(
        title=_(u"licenza_distribuzione", default=u"Licenza di distribuzione"),
        required=False,
    )

    # TODO: usare vocabolario dinamico per i servizi collegati?
    servizi_collegati = RelationList(
        title=u"Servizi collegati",
        default=[],
        value_type=RelationChoice(
            title=_(u"Servizio collegato"), vocabulary="plone.app.vocabularies.Catalog"
        ),
        required=False,
    )

    canale_digitale_servizio = schema.TextLine(
        title=_(
            u"canale_digitale_servizio", default=u"Canale digitale servizio collegato"
        ),
        required=False,
    )

    data_inizio = schema.Date(
        title=_(u"data_inizio", default=u"Data di inizio"), required=False
    )

    data_e_fasi_intermedie = RichText(
        title=_(u"data_e_fasi_intermedie", default=u"Data e fasi intermedie"),
        required=False,
    )

    data_inizio = schema.Date(
        title=_(u"data_inizio", default=u"Data di inizio"), required=False
    )

    # TODO: vocabolario per i dataset collegati ad un documento
    dataset = RelationList(
        title=_(u"Dataset"),
        required=False,
        default=[],
        value_type=RelationChoice(
            title=_(u"Dataset collegato"), vocabulary="plone.app.vocabularies.Catalog"
        ),
    )

    informazioni = RichText(
        title=_(u"informazioni", default=u"Ulteriori informazioni"), required=False
    )

    riferimenti_normativi = RichText(
        title=_(u"riferimenti_normativi", default=u"Riferimenti normativi"),
        required=False,
    )



# -*- coding: utf-8 -*-
from design.plone.contenttypes.controlpanels.vocabularies import (
    IVocabulariesControlPanel,
)
from design.plone.contenttypes.testing import (
    DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
)
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from zope.component import getUtility
from zope.schema.interfaces import IVocabularyFactory

import unittest


class TestControlpanelVocabularies(unittest.TestCase):
    layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])

        api.portal.set_registry_record(
            "tipologie_notizia",
            ["xxx", "yyy"],
            interface=IVocabulariesControlPanel,
        )
        api.portal.set_registry_record(
            "tipologie_unita_organizzativa",
            ["foo", "bar"],
            interface=IVocabulariesControlPanel,
        )

        api.portal.set_registry_record(
            "lead_image_dimension",
            ["News Item|1920x600", "UnitaOrganizzativa|900x900"],
            interface=IVocabulariesControlPanel,
        )

    def test_tipologia_notizia_vocab(self):
        factory = getUtility(
            IVocabularyFactory, "design.plone.vocabularies.tipologie_notizia"
        )
        vocab = factory(self.portal)
        self.assertEqual(["", "xxx", "yyy"], [(x.value) for x in vocab])

    def test_tipologie_unita_organizzativa_vocab(self):
        factory = getUtility(
            IVocabularyFactory,
            "design.plone.vocabularies.tipologie_unita_organizzativa",
        )
        vocab = factory(self.portal)
        self.assertEqual(["", "foo", "bar"], [(x.value) for x in vocab])

    def test_dimensioni_immagini(self):
        factory = getUtility(
            IVocabularyFactory,
            "design.plone.vocabularies.leadimage_dimension",
        )
        vocab = factory(self.portal)

        terms = {x.token: x.title for x in vocab}
        self.assertTrue("News Item" in terms)
        self.assertTrue(terms["News Item"] == "1920x600")
        self.assertTrue("UnitaOrganizzativa" in terms)
        self.assertTrue(terms["UnitaOrganizzativa"] == "900x900")



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from design.plone.contenttypes.interfaces import IDesignPloneContenttypesLayer
from plone import api
from plone.dexterity.interfaces import IDexterityContainer
from plone.dexterity.interfaces import IDexterityContent
from plone.restapi.interfaces import ISerializeToJson
from zope.component import adapter
from zope.i18n import translate
from zope.interface import implementer
from plone.restapi.serializer.dxcontent import (
    SerializeToJson as BaseSerializer,
)
from plone.restapi.serializer.dxcontent import (
    SerializeFolderToJson as BaseFolderSerializer,
)


@implementer(ISerializeToJson)
@adapter(IDexterityContent, IDesignPloneContenttypesLayer)
class SerializeToJson(BaseSerializer):
    def __call__(self, version=None, include_items=True):
        result = super(SerializeToJson, self).__call__(
            version=version, include_items=include_items
        )
        ttool = api.portal.get_tool("portal_types")
        if self.context.portal_type == "News Item":
            result["design_italia_meta_type"] = translate(
                self.context.tipologia_notizia,
                domain=_._domain,
                context=self.request,
            )
        else:
            result["design_italia_meta_type"] = translate(
                ttool[self.context.portal_type].Title(), context=self.request
            )
        return result


@implementer(ISerializeToJson)
@adapter(IDexterityContainer, IDesignPloneContenttypesLayer)
class SerializeFolderToJson(BaseFolderSerializer):
    def __call__(self, version=None, include_items=True):
        result = super(SerializeFolderToJson, self).__call__(
            version=version, include_items=include_items
        )
        result["@id"] = self.context.absolute_url()
        ttool = api.portal.get_tool("portal_types")
        if self.context.portal_type == "News Item":
            result["design_italia_meta_type"] = translate(
                self.context.tipologia_notizia,
                domain=_._domain,
                context=self.request,
            )
        else:
            result["design_italia_meta_type"] = translate(
                ttool[self.context.portal_type].Title(), context=self.request
            )
        if "items_total" not in result:
            # siamo in un sotto-elemento di quello richiesto dalla query.
            #  ritorniamo il numero di elementi totale, senza doverli ritornare
            # effettivamente.
            result[
                "items_total"
            ] = self.context.getFolderContents().actual_result_count
        return result



# -*- coding: utf-8 -*-
from plone.restapi.services.types.get import TypesGet as BaseGet
from zope.interface import implementer
from zope.publisher.interfaces import IPublishTraverse
from design.plone.contenttypes.controlpanels.geolocation_defaults import (
    IGeolocationDefaults,
)
from zope.i18n import translate
from plone import api
from design.plone.contenttypes import _


class FieldsetsMismatchError(Exception):
    """Exception thrown when we try to reorder fieldsets, but the order list is
    different from the fieldsets returned from Plone
    """


FIELDSETS_ORDER = {
    "Document": [
        "default",
        "testata",
        "settings",
        "correlati",
        "categorization",
        "dates",
        "ownership",
        "layout",
    ],
    "Documento": [
        "default",
        "descrizione",
        "accedere_al_servizio",
        "informazioni",
        "settings",
        "correlati",
        "categorization",
        "dates",
        "ownership",
    ],
    "Event": [
        "default",
        "cose",
        "luogo",
        "date_e_orari",
        "costi",
        "contatti",
        "informazioni",
        "correlati",
        "categorization",
        "dates",
        "settings",
        "layout",
        "ownership",
    ],
    "News Item": [
        "default",
        "dates",
        "correlati",
        "categorization",
        "settings",
        "ownership",
        "layout",
    ],
    "Modulo": [
        "default",
        "settings",
        "correlati",
        "categorization",
        "dates",
        "ownership",
    ],
    "Pagina Argomento": [
        "default",
        "informazioni",
        "correlati",
        "categorization",
        "dates",
        "settings",
        "layout",
        "ownership",
    ],
    "Persona": [
        "default",
        "ruolo",
        "contatti",
        "documenti",
        "informazioni",
        "correlati",
        "categorization",
        "dates",
        "ownership",
        "settings",
    ],
    "Servizio": [
        "default",
        "cose",
        "a_chi_si_rivolge",
        "accedi_al_servizio",
        "cosa_serve",
        "costi_e_vincoli",
        "tempi_e_scadenze",
        "casi_particolari",
        "contatti",
        "documenti",
        "link_utili",
        "informazioni",
        "correlati",
        "categorization",
        "settings",
        "ownership",
        "dates",
    ],
    "UnitaOrganizzativa": [
        "default",
        "cosa_fa",
        "struttura",
        "persone",
        "contatti",
        "correlati",
        "categorization",
        "informazioni",
        "settings",
        "ownership",
        "dates",
    ],
    "Venue": [
        "default",
        "descrizione",
        "accesso",
        "dove",
        "orari",
        "contatti",
        "informazioni",
        "correlati",
        "categorization",
    ],
}


@implementer(IPublishTraverse)
class TypesGet(BaseGet):
    def customize_persona_schema(self, result):
        msgid = _(u"Nome e Cognome", default="Nome e cognome")
        result["properties"]["title"]["title"] = translate(
            msgid, context=self.request
        )
        return result

    def customize_venue_schema(self, result):
        """
        Unico modo per spostare il campo "notes"
        """
        for fieldset in result["fieldsets"]:
            if (
                fieldset.get("id") == "default"
                and "notes" in fieldset["fields"]
            ):
                fieldset["fields"].remove("notes")
            if (
                fieldset.get("id") == "dove"
                and "notes" not in fieldset["fields"]
            ):
                fieldset["fields"].append("notes")

        return result

    def customize_versioning_fields_fieldset(self, result):
        """
        Unico modo per spostare i campi del versioning.
        Perché changeNotes ha l'order after="*" che vince su tutto.
        """
        versioning_fields = ["versioning_enabled", "changeNote"]
        for field in versioning_fields:
            found = False
            for fieldset in result["fieldsets"]:
                if (
                    fieldset.get("id") == "default"
                    and field in fieldset["fields"]
                ):
                    found = True
                    fieldset["fields"].remove(field)
                if fieldset.get("id") == "settings" and found:
                    fieldset["fields"].append(field)

        return result

    def reply(self):
        result = super(TypesGet, self).reply()

        if "fieldsets" in result:
            result["fieldsets"] = self.reorder_fieldsets(
                original=result["fieldsets"]
            )
        pt = self.request.PATH_INFO.split("/")[-1]

        if "properties" in result:
            if pt == "Venue":
                if "country" in result["properties"]:
                    if not result["properties"]["country"].get("default", ""):
                        result["properties"]["country"]["default"] = {
                            "title": "Italia",
                            "token": "380",
                        }
                if "city" in result["properties"]:
                    if not result["properties"]["city"].get("default", ""):
                        result["properties"]["city"][
                            "default"
                        ] = api.portal.get_registry_record(
                            "city", interface=IGeolocationDefaults
                        )
                if "zip_code" in result["properties"]:
                    if not result["properties"]["zip_code"].get("default", ""):
                        result["properties"]["zip_code"][
                            "default"
                        ] = api.portal.get_registry_record(
                            "zip_code", interface=IGeolocationDefaults
                        )

                if "street" in result["properties"]:
                    if not result["properties"]["street"].get("default", ""):
                        result["properties"]["street"][
                            "default"
                        ] = api.portal.get_registry_record(
                            "street", interface=IGeolocationDefaults
                        )

                if "geolocation" in result["properties"]:
                    if not result["properties"]["geolocation"].get(
                        "default", {}
                    ):
                        result["properties"]["geolocation"]["default"] = eval(
                            api.portal.get_registry_record(
                                "geolocation", interface=IGeolocationDefaults
                            )
                        )

        # be careful: result could be dict or list. If list it will not
        # contains title. And this is ok for us.
        pt = self.request.PATH_INFO.split("/")[-1]

        if "title" in result:
            if pt == "Persona":
                result = self.customize_persona_schema(result)
            if pt == "Venue":
                result = self.customize_venue_schema(result)
            result = self.customize_versioning_fields_fieldset(result)
        return result

    def reorder_fieldsets(self, original):
        pt = self.request.PATH_INFO.split("/")[-1]
        # makea copy
        order = [x for x in FIELDSETS_ORDER.get(pt, [])]
        if not order:
            # no match
            return original
        actual = [x["id"] for x in original]
        portal_types = api.portal.get_tool(name="portal_types")
        service_behaviors = portal_types["Servizio"].behaviors
        if (
            "design.plone.contenttypes.behavior.trasparenza"
            in service_behaviors
        ):
            order.append("trasparenza")

        if set(order) != set(actual):
            # list mismatch
            raise FieldsetsMismatchError(
                "Fieldset mismatch for {}. expected: {} get: {}".format(
                    pt, order, actual
                )
            )
        new = []
        for id in order:
            for fieldset in original:
                if fieldset["id"] == id:
                    new.append(fieldset)
        if not new:
            # no match
            new = original
        return new



# -*- coding: utf-8 -*-

from design.plone.contenttypes.testing import (
    DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
)
from plone import api
import unittest


class TestDocument(unittest.TestCase):
    layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]

    def test_behaviors_enabled_for_documento(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["CartellaModulistica"].behaviors,
            (
                "plone.namefromtitle",
                "plone.allowdiscussion",
                "plone.excludefromnavigation",
                "plone.shortname",
                "plone.ownership",
                "plone.publication",
                "plone.categorization",
                "plone.basic",
                "plone.locking",
                "volto.blocks",
            ),
        )

    def test_event_addable_types(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            ("Document", "Documento", "Link"),
            portal_types["CartellaModulistica"].allowed_content_types,
        )



# -*- coding: utf-8 -*-
from Products.CMFPlone.utils import safe_hasattr
from pkg_resources import get_distribution
from pkg_resources import parse_version
from plone.restapi.deserializer import json_body
from plone.restapi.services import Service
from Products.CMFPlone.interfaces import IPloneSiteRoot
from zope.component import getMultiAdapter
from plone.app.querystring import queryparser
from plone.app.event.base import expand_events
from plone.app.event.recurrence import EventOccurrenceAccessor
from plone.app.event.dx.behaviors import EventAccessor
from DateTime import DateTime

zcatalog_version = get_distribution("Products.ZCatalog").version
if parse_version(zcatalog_version) >= parse_version("5.1"):
    SUPPORT_NOT_UUID_QUERIES = True
else:
    SUPPORT_NOT_UUID_QUERIES = False


class ScadenziarioSearchPost(Service):
    """
    Ritorna la lista dei giorni in cui sono presenti elementi da visualizzare
    {
        "@id": "http://localhost:9080/Plone/@scadenziario",
        "items": [
            "2020/11/19",
            "2020/11/26",
            "2020/12/17",
            "2020/12/24",
            "2020/12/31",
            "2021/01/07"
        ]
    }
    """

    def reply(self):
        data = json_body(self.request)
        query = data.get("query", None)
        # b_start = int(data.get("b_start", 0))
        # b_size = int(data.get("b_size", 25))
        sort_on = data.get("sort_on", None)
        sort_order = data.get("sort_order", None)
        limit = int(data.get("limit", 1000))
        # fullobjects = data.get("fullobjects", False)

        if query is None:
            raise Exception("No query supplied")

        if sort_order:
            sort_order = "descending" if sort_order else "ascending"

        querybuilder = getMultiAdapter(
            (self.context, self.request), name="querybuilderresults"
        )
        querybuilder_parameters = dict(
            query=query,
            brains=True,
            # b_start=b_start,
            # b_size=b_size,
            sort_on=sort_on,
            sort_order=sort_order,
            limit=limit,
        )

        # Exclude "self" content item from the results when ZCatalog supports
        # NOT UUID
        # queries and it is called on a content object.
        if (
            not IPloneSiteRoot.providedBy(self.context)
            and SUPPORT_NOT_UUID_QUERIES
        ):
            querybuilder_parameters.update(
                dict(custom_query={"UID": {"not": self.context.UID()}})
            )

        # Ottieni tutti i risultati
        results = querybuilder(**querybuilder_parameters)

        # preparati per l'expand degli eventi.
        not_events = [x for x in results if x.portal_type != "Event"]
        events = [x for x in results if x.portal_type == "Event"]
        # prende la query e la trasforma in una query per il catalogo
        # così poi se e quando dobbiamo litigare con delle ricorrenze e date
        # di start ed end, le abbiamo già calcolate, come plone le proporrebbe
        # al catalogo
        query_for_catalog = queryparser.parseFormquery(
            self.context, query, sort_on=sort_on, sort_order=sort_order
        )
        start = None
        end = None
        if "start" in query_for_catalog:
            start = query_for_catalog["start"]["query"]
        if "end" in query_for_catalog:
            end = query_for_catalog["end"]["query"]
        expanded_events = expand_events(events, 3, start, end)

        all_results = not_events + expanded_events
        brains_grouped = {}
        for brain in all_results:
            if not safe_hasattr(brain, "start") or not brain.start:
                continue
            brains_grouped.setdefault(
                brain.start.strftime("%Y/%m/%d"), []
            ).append(brain)
        keys = list(brains_grouped.keys())
        if sort_order:
            keys.sort(reverse=True)
        else:
            keys.sort()

        return {"@id": self.request.get("URL"), "items": keys}


class ScadenziarioDayPost(Service):
    def reply(self):
        data = json_body(self.request)
        query = data.get("query", None)
        sort_on = data.get("sort_on", None)
        sort_order = data.get("sort_order", None)

        if query is None:
            raise Exception("No query supplied")

        if sort_order:
            sort_order = "descending" if sort_order else "ascending"

        # results = querybuilder(**querybuilder_parameters)
        # Seems that origina querybuilder is not able to handle event search on
        # a single day... I can handle this calling catalog and going through
        # DateTime conversion
        query_for_catalog = queryparser.parseFormquery(
            self.context, query, sort_on=sort_on, sort_order=sort_order
        )
        query_for_catalog["start"]["query"][0] = DateTime(
            query_for_catalog["start"]["query"][0]
        )
        query_for_catalog["start"]["query"][1] = DateTime(
            query_for_catalog["start"]["query"][1]
        )
        results = self.context.portal_catalog(query_for_catalog)
        # preparati per l'expand degli eventi.
        not_events = [x for x in results if x.portal_type != "Event"]
        events = [x for x in results if x.portal_type == "Event"]
        start = None
        end = None
        # qui ce l'abbiamo per forza start
        if "start" in query_for_catalog:
            start = query_for_catalog["start"]["query"]
        if "end" in query_for_catalog:
            end = query_for_catalog["end"]["query"]

        expanded_events = expand_events(events, 3, start, end)
        start_date = start[0].strftime("%Y/%m/%d")
        correct_events = []
        for x in expanded_events:
            if start_date == x.start.strftime("%Y/%m/%d"):
                correct_events.append(x)

        all_results = not_events + correct_events

        brains_grouped = {}
        for brain in all_results:
            if not safe_hasattr(results[0], "start"):
                continue
            brains_grouped.setdefault(
                brain.start.strftime("%Y/%m/%d"), []
            ).append(brain)

        keys = list(brains_grouped.keys())
        keys.sort()

        results_to_be_returned = {}
        for key in keys:
            results_to_be_returned[key] = []
            for brain in brains_grouped[key]:
                if isinstance(brain, (EventAccessor, EventOccurrenceAccessor)):
                    if brain.context.portal_type == "Occurrence":
                        url = brain.url[:-10]
                    else:
                        url = brain.url
                    results_to_be_returned[key].append(
                        {
                            "@id": url,
                            "id": brain.id,
                            "title": brain.title,
                            "text": brain.description,
                            "start": brain.start.strftime("%Y/%m/%d"),
                            "type": self.context.translate("Event"),
                            "category": brain.subjects,
                        }
                    )
                else:
                    results_to_be_returned[key].append(
                        {
                            "@id": brain.getURL(),
                            "id": brain.getId,
                            "title": brain.Title,
                            "text": brain.Description,
                            "start": brain.start.strftime("%Y/%m/%d"),
                            "type": self.context.translate(brain.portal_type),
                            "category": brain.subject,
                        }
                    )
                results_to_be_returned[key].sort(key=lambda x: x["title"])
        return {
            "@id": self.request.get("URL"),
            "items": results_to_be_returned,
        }



# -*- coding: utf-8 -*-
from collective import dexteritytextindexer
from design.plone.contenttypes import _
from design.plone.contenttypes.interfaces.documento import IDocumento
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.dexterity.interfaces import IDexterityContent
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice, RelationList
from zope.component import adapter
from zope.interface import provider, implementer
from design.plone.contenttypes.interfaces.bando import IBandoAgidSchema


class IArgomentiSchema(model.Schema):
    """Marker interface for Argomenti"""

    tassonomia_argomenti = RelationList(
        title=_("tassonomia_argomenti_label", default="Tassonomia argomenti"),
        description=_(
            "tassonomia_argomenti_help",
            default="Seleziona una lista di argomenti d'interesse per questo"
            " contenuto.",
        ),
        value_type=RelationChoice(
            title=_(u"Argomenti correlati"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
        required=False,
        default=[],
    )
    correlato_in_evidenza = RelationList(
        title=_(
            "correlato_in_evidenza_label", default="Correlato in evidenza"
        ),
        description=_(
            "correlato_in_evidenza_help",
            default="Seleziona un correlato da mettere in evidenza."
            " contenuto.",
        ),
        value_type=RelationChoice(
            title=_(u"Correlato in evidenza"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
        required=False,
        default=[],
    )

    form.widget(
        "tassonomia_argomenti",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 20,
            "selectableTypes": ["Pagina Argomento"],
        },
    )
    form.widget(
        "correlato_in_evidenza",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={"maximumSelectionSize": 1},
    )

    dexteritytextindexer.searchable("tassonomia_argomenti")


@provider(IFormFieldProvider)
class IArgomenti(IArgomentiSchema):
    """ """

    model.fieldset(
        "correlati",
        label=_("correlati_label", default="Contenuti collegati"),
        fields=["correlato_in_evidenza"],
    )
    form.order_after(correlato_in_evidenza="IRelatedItems.relatedItems")


@provider(IFormFieldProvider)
class IArgomentiDocumento(IArgomentiSchema):
    """ """

    model.fieldset(
        "correlati",
        label=_("correlati_label", default="Contenuti collegati"),
        fields=["correlato_in_evidenza"],
    )
    form.order_after(correlato_in_evidenza="IRelatedItems.relatedItems")
    form.order_after(tassonomia_argomenti="IDublinCore.title")


@provider(IFormFieldProvider)
class IArgomentiBando(IArgomentiSchema):
    """ """

    model.fieldset(
        "correlati",
        label=_("correlati_label", default="Contenuti collegati"),
        fields=["tassonomia_argomenti", "correlato_in_evidenza"],
    )
    form.order_before(tassonomia_argomenti="IRelatedItems.relatedItems")
    form.order_after(correlato_in_evidenza="IRelatedItems.relatedItems")


@implementer(IArgomenti)
@adapter(IDexterityContent)
class Argomenti(object):
    """"""

    def __init__(self, context):
        self.context = context


@implementer(IArgomentiDocumento)
@adapter(IDocumento)
class ArgomentiDocumento(object):
    """"""

    def __init__(self, context):
        self.context = context


@implementer(IArgomentiBando)
@adapter(IBandoAgidSchema)
class ArgomentiBando(object):
    """"""

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from design.plone.contenttypes import _
from plone.app.textfield import RichText
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.autoform import directives as form
from plone.autoform.interfaces import IFormFieldProvider
from plone.dexterity.interfaces import IDexterityContent
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from zope import schema
from zope.component import adapter
from zope.interface import provider, implementer


@provider(IFormFieldProvider)
class IEvento(model.Schema):
    """Marker inteerface for content type Evento
    """

    sottotitolo = schema.TextLine(
        title=_(u"sottotitolo_label", default=u"Sottotitolo"),
        description=_(
            "sottotitolo_help",
            default="Indica un eventuale sottotitolo/titolo alternativo.",
        ),
        required=False,
    )

    descrizione_destinatari = RichText(
        title=_(
            u"descrizione_destinatari", default=u"Descrizione destinatari"
        ),
        required=False,
        description=_(
            "descrizione_destinatari_help",
            default="Descrizione dei principali interlocutori dell'evento.",
        ),
    )

    persone_amministrazione = RelationList(
        title=u"Persone dell'amministrazione che partecipano all'evento",
        default=[],
        value_type=RelationChoice(
            title=_(u"Persona dell'amministrazione"),
            vocabulary="plone.app.vocabularies.Catalog",
        ),
        description=_(
            "persone_amministrazione_help",
            default="Elenco delle persone dell'amministrazione che"
            " parteciperanno all'evento.",
        ),
        required=False,
    )

    orari = RichText(
        title=_(u"orari", default=u"Informazioni sugli orari"),
        required=False,
        description=_(
            "orari_help",
            default="Informazioni sugli orari di svolgimento dell'evento.",
        ),
    )

    prezzo = RichText(
        title=_(u"prezzo", default=u"Prezzo"),
        required=False,
        description=_(
            "prezzo_help",
            default="Indicare il prezzo dell'evento, se presente, specificando"
            " se esistono formati diversi.",
        ),
    )
    organizzato_da_interno = RelationList(
        title=_(u"organizzato_da_interno_label", default=u"Organizzato da"),
        default=[],
        value_type=RelationChoice(vocabulary="plone.app.vocabularies.Catalog"),
        required=False,
        description=_(
            "organizzato_da_interno_help",
            default="Se l'evento è organizzato direttamente dal comune,"
            " indicare l'ufficio/ente organizzatore. I dati di contatto "
            "verranno presi direttamente dall'ufficio selezionato. Se l'evento"
            " non è organizzato direttamente dal comune, o si vogliono "
            "sovrascrivere alcuni dati di contatto, utilizzare i seguenti campi.",  # noqa
        ),
    )

    organizzato_da_esterno = RichText(
        title=_(u"organizzato_da_esterno_label", default=u"Organizzatore"),
        required=False,
        description=_(
            "organizzato_da_esterno_help",
            default="Se l'evento non è organizzato direttamente dal comune oppure ha anche un organizzatore esterno,"
            " indicare il nome del contatto.",
        ),
    )
    telefono = schema.TextLine(
        title=_(u"telefono_event_help", default=u"Telefono"),
        description=_(
            u"telefono_event_label",
            default=u"Indicare un riferimento telefonico per poter contattare"
            " gli organizzatori.",
        ),
        required=False,
    )
    fax = schema.TextLine(
        title=_(u"fax_event_help", default=u"Fax"),
        description=_(
            u"fax_event_label", default="Indicare un numero di fax."
        ),
        required=False,
    )
    reperibilita = schema.TextLine(
        title=_(u"reperibilita", default=u"Reperibilità organizzatore"),
        required=False,
        description=_(
            "reperibilita_help",
            default="Indicare gli orari in cui l'organizzatore è"
            " telefonicamente reperibile.",
        ),
    )
    email = schema.TextLine(
        title=_(u"email_event_label", default=u"E-mail"),
        description=_(
            u"email_event_help",
            default=u"Indicare un indirizzo mail per poter contattare"
            " gli organizzatori.",
        ),
        required=False,
    )

    web = schema.TextLine(
        title=_(u"web_event_label", default=u"Sito web"),
        description=_(
            "web_event_help",
            default="Indicare un indirizzo web di riferimento a "
            "questo evento.",
        ),
        required=False,
    )
    supportato_da = RelationList(
        title=_(u"supportato_da_label", default=u"Evento supportato da"),
        required=False,
        default=[],
        value_type=RelationChoice(vocabulary="plone.app.vocabularies.Catalog"),
        description=_(
            "supportato_da_help",
            default="Indicare gli uffici/enti che supportano l'evento.",
        ),
    )

    # TODO: come fare il rating/recensione dell'evento

    patrocinato_da = schema.TextLine(
        title=_(u"patrocinato_da_label", default=u"Patrocinato da"),
        required=False,
        description=_(
            "patrocinato_da_help",
            default="Indicare l'ente che supporta l'evento, se presente.",
        ),
    )

    # custom widgets
    form.widget(
        "supportato_da",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 1,
            "selectableTypes": ["UnitaOrganizzativa"],
        },
    )
    form.widget(
        "organizzato_da_interno",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 10,
            "selectableTypes": ["Persona", "UnitaOrganizzativa", "Servizio"],
        },
    )
    form.widget(
        "persone_amministrazione",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "maximumSelectionSize": 10,
            "selectableTypes": ["Persona"],
        },
    )

    # custom fieldsets and order
    form.order_before(sottotitolo="ILeadImageBehavior.image")
    model.fieldset(
        "cose",
        label=_("cose_label", default=u"Cos'è"),
        fields=["descrizione_destinatari", "persone_amministrazione"],
    )
    model.fieldset(
        "date_e_orari",
        label=_("date_e_orari_label", default=u"Date e orari"),
        fields=["orari"],
    )
    model.fieldset(
        "costi", label=_("costi_label", default=u"Costi"), fields=["prezzo"]
    )
    model.fieldset(
        "contatti",
        label=_("contatti_label", default=u"Contatti"),
        fields=[
            "organizzato_da_interno",
            "organizzato_da_esterno",
            "telefono",
            "fax",
            "reperibilita",
            "email",
            "web",
            "supportato_da",
        ],
    )
    model.fieldset(
        "informazioni",
        label=_("informazioni_label", default=u"Ulteriori informazioni"),
        fields=["patrocinato_da"],
    )


@implementer(IEvento)
@adapter(IDexterityContent)
class Evento(object):
    """
    """

    def __init__(self, context):
        self.context = context



# -*- coding: utf-8 -*-
from plone.formwidget.geolocation.interfaces import IGeolocationField
from plone.dexterity.interfaces import IDexterityContent
from plone.restapi.interfaces import IFieldDeserializer
from zope.component import adapter
from zope.interface import implementer
from zope.publisher.interfaces.browser import IBrowserRequest
from plone.restapi.deserializer.dxfields import DefaultFieldDeserializer
from plone.formwidget.geolocation.geolocation import Geolocation
from design.plone.contenttypes import _
from zope.i18n import translate


@implementer(IFieldDeserializer)
@adapter(IGeolocationField, IDexterityContent, IBrowserRequest)
class GeolocationFieldDeserializer(DefaultFieldDeserializer):
    def __call__(self, value):
        if "latitude" not in value or "longitude" not in value:
            raise ValueError(
                translate(
                    _(
                        "geolocation_field_validator_label",
                        default="Invalid geolocation data: ${value}. Provide latitude and longitude coordinates.",  # noqa
                        mapping={"value": value},
                    ),
                    context=self.request,
                )
            )
        return Geolocation(latitude=value["latitude"], longitude=value["longitude"])
